@@ -168,23 +168,30 @@ class MyWhatify:
         return source_id
 
     @classmethod
-    def preparing_data_set(cls, source_id, data_set_name, sample_id=['car_id'],
+    def preparing_data_set_automation(cls, source_id, data_set_name, sample_id=['car_id'],
                            retype_columns={'car_id': FeatureType.CATEGORICAL}, target='class',
                            problem_type=ProblemType.CLASSIFICATION, wait=True):
+        return cls.preparing_data_set(source_id=source_id, data_set_name=data_set_name, sample_id=sample_id,
+                                      retype_columns=retype_columns, target=target,
+                                      problem_type=problem_type, wait=wait)
+
+    @classmethod
+    def preparing_data_set(cls, source_id: int, data_set_name: str, target: str = 'class',
+                           problem_type: ProblemType = ProblemType.CLASSIFICATION, header: bool = True,
+                           na_values = None, retype_columns = None, rename_columns = None, datetime_format: str = None,
+                           time_axis: str = None, block_id = None, sample_id = None, subdataset_id = None,
+                           sample_weight = None, not_used = None, wait: bool = True,
+                           skip_if_exists: bool = True):
         with allure.step('Preparing Dataset name: ' + str(data_set_name) + ' source_id= ' + str(source_id) +
                          ' problem_type: ' + str(problem_type) + ' target: ' + str(target) + ' wait: ' + str(wait)):
             dataset_id = -1
-            # task_type = eval(problem_type.value)
-
             try:
                 dataset_id = my_toolkit.resources.Datasource.prepare_data(
-                    datasource_id=source_id,
-                    dataset_name=data_set_name,
-                    target=target,
-                    problem_type=problem_type,
-                    sample_id=sample_id,
-                    retype_columns=retype_columns,
-                    wait=wait, skip_if_exists=True)['id']
+                    datasource_id=source_id, dataset_name=data_set_name, target=target, problem_type=problem_type,
+                    sample_id=sample_id, retype_columns=retype_columns, header=header, na_values=na_values,
+                    rename_columns=rename_columns, datetime_format=datetime_format, time_axis=time_axis,
+                    block_id=block_id, subdataset_id=subdataset_id, sample_weight=sample_weight, not_used=not_used,
+                    wait=wait, skip_if_exists=skip_if_exists)['id']
                 print("Dataset {} id is {}".format(data_set_name, dataset_id))
             except Exception as e:
                 logging.exception('failed preparing data set' + data_set_name + ' got error: ' + e)
@@ -192,7 +199,9 @@ class MyWhatify:
 
     @classmethod
     def create_data_set(cls, source_id, data_set_name, problem_type=ProblemType.CLASSIFICATION, target='class',
-                        not_used=None, na_values=None, skip_if_exists=True, wait=True):
+                        not_used=None, na_values=None, retype_columns=None, rename_columns=None, sample_id=None,
+                        datetime_format=None, time_axis=None, block_id=None, subdataset_id=None, sample_weight=None,
+                        hidden=None, skip_if_exists=True, wait=True):
         with allure.step('Preparing Dataset name: ' + str(data_set_name) + ' source_id= ' + str(source_id) +
                          ' problem_type: ' + str(problem_type) + ' target: ' + str(target) + ' wait: ' + str(wait)):
             dataset_id = -1
@@ -202,6 +211,10 @@ class MyWhatify:
                 dataset_id = my_toolkit.Dataset.create(datasource_id=source_id, dataset_name=data_set_name,
                                                        problem_type=task_type, target=target, not_used=not_used,
                                                        na_values=na_values,  skip_if_exists=skip_if_exists,
+                                                       sample_id=sample_id, retype_columns=retype_columns,
+                                                       rename_columns=rename_columns, datetime_format=datetime_format,
+                                                       time_axis=time_axis, block_id=block_id, hidden=hidden,
+                                                       sample_weight=sample_weight, subdataset_id=subdataset_id,
                                                        wait=True)['id']
                 print("Dataset {} id is {}".format(data_set_name, dataset_id))
             except Exception as e:
